Builder

Struct Builder 

pub struct Builder<Tls = TlsUnset> { /* private fields */ }
Builder for a hyper-backed HttpClient implementation.

This builder can be used to customize the underlying TCP connector used, as well as hyper client configuration.

Examples

Construct a Hyper client with the RusTLS TLS implementation. This can be useful when you want to share a Hyper connector between multiple generated Smithy clients.

Implementations

Source

impl Builder<TlsProviderSelected>

pub fn build_https(self) -> SharedHttpClient

Create an HTTPS client with the selected TLS provider.

The trusted certificates will be loaded later when this becomes the selected HTTP client for a Smithy client.

pub fn build_with_resolver( self, resolver: impl ResolveDns + Clone + 'static, ) -> SharedHttpClient

Create an HTTPS client using a custom DNS resolver

pub fn tls_context(self, ctx: TlsContext) -> Self

Configure the TLS context

Source

impl<Any> Builder<Any>

pub fn pool_idle_timeout<D>(self, val: D) -> Self
where D: Into<Option<Duration>>,

Set an optional timeout for idle sockets being kept-alive.

Pass None to disable timeout.

Defaults to Hyper’s default timeout, which is currently 90 seconds - see hyper_util::client::legacy::Builder::pool_idle_timeout, but unlike that function, there is no need to call pool_timer yourself.

Examples
use aws_smithy_http_client::{Builder, tls};
use std::time::Duration;

let client = Builder::new()
    .pool_idle_timeout(Duration::from_secs(30))
    .tls_provider(tls::Provider::Rustls(tls::rustls_provider::CryptoMode::AwsLc))
    .build_https();
pub fn set_pool_idle_timeout( &mut self, val: Option<Option<Duration>>, ) -> &mut Self

Set an optional timeout for idle sockets being kept-alive.

Pass None to use Hyper’s default timeout, Some(None) to disable timeouts.

This is the mutable version of pool_idle_timeout.

Examples
use std::time::Duration;
use aws_smithy_http_client::{Builder, tls};

let mut client = Builder::new();
client.set_pool_idle_timeout(Some(Some(Duration::from_secs(30))));
client
    .tls_provider(tls::Provider::Rustls(tls::rustls_provider::CryptoMode::AwsLc))
    .build_https();
pub fn pool_max_idle_per_host(self, val: usize) -> Self

Sets the maximum number of idle pooled connections allowed per host.

Default is determined by the underlying hyper client, which is currently no limit (usize::MAX) - see hyper_util::client::legacy::Builder::pool_max_idle_per_host.

Examples
use aws_smithy_http_client::{Builder, tls};

let client = Builder::new()
    .pool_max_idle_per_host(70)
    .tls_provider(tls::Provider::Rustls(tls::rustls_provider::CryptoMode::AwsLc))
    .build_https();
pub fn set_pool_max_idle_per_host(&mut self, val: Option<usize>) -> &mut Self

Sets the maximum number of idle pooled connections allowed per host.

Pass None to use the hyper default (currently no limit, usize::MAX) - see hyper_util::client::legacy::Builder::pool_max_idle_per_host.

This is the mutable version of pool_max_idle_per_host.

Source

impl Builder<TlsUnset>

pub fn new() -> Self

Creates a new builder.

pub fn tls_provider(self, provider: Provider) -> Builder<TlsProviderSelected>

Set the TLS implementation to use