pub struct Connector { /* private fields */ }Expand description
HttpConnector used to make HTTP requests.
This connector also implements socket connect and read timeouts.
This shouldn’t be used directly in most cases.
See the docs on Builder for examples of how to customize the HTTP client.
Implementations